pub struct LoopId(/* private fields */);Expand description
One loop, by number.
A handle rather than a reference, because a loop’s parent and children are loops and a tree of references to each other is not a thing to hand a pass.
Implementations